# Copyright 2016-2018 Ioan Vancea, Markus Scheidgen
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#   http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

##
# A script to create a new schema and a new table to contain
# the data history statistics for main DB. The same database is used.
# RUN: python create_stats_table.py
# - will create a new schema: data_history
# - will create a new table: stats
#           - id: primary key
#           - date: the date when the statistics were collected
#           - summary: a json which contains the collected data
# Note: Marshmallow related data is not needed here, could be removed
##

import datetime
from flask import Flask
from flask_sqlalchemy import SQLAlchemy
from sqlalchemy.dialects.postgresql import JSON
from flask_marshmallow import Marshmallow

tb_schema = 'data_history'

app = Flask(__name__)

# apply configuration
app.config['SQLALCHEMY_DATABASE_URI'] = 'postgresql://nomadapp:Nomad_Flask@localhost/nomaddb'
# app.config.from_object('app.config')
# app.config['SQLALCHEMY_DATABASE_URI'] = 'postgresql://localhost/nomaddb'
app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
app.config['SQLALCHEMY_ECHO'] = True

db = SQLAlchemy(app)
ma = Marshmallow(app)


class Stats(db.Model):
    __tablename__ = 'stats'
    __table_args__ = {'schema': tb_schema}

    id = db.Column(db.Integer, primary_key=True)
    date = db.Column(db.Date, default=datetime.date.today(),
                     nullable=False, index=True)
    summary = db.Column(JSON, nullable=False)


class StatsSchema(ma.ModelSchema):

    class Meta:
        model = Stats
    date = ma.DateTime(format="%d-%m-%Y")


stats_schema = StatsSchema()
m_stats_schema = StatsSchema(many=True)


if __name__ == '__main__':
    from sqlalchemy.schema import CreateSchema
    # create the new DB schema
    db.engine.execute(CreateSchema(tb_schema))
    # create the new table
    db.create_all()
    # app.run()
